Environment class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getArguments() List<String>
Get the POSIX-style arguments to the program.
getEnvironment() List<(String, String)>
Get the POSIX-style environment variables.
getInitialCwd() → dynamic
Return a path that programs should use as their initial current working directory, interpreting . as shorthand for this.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited