Exit class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exit({required Result<void, void> status}) → void
Exit the current instance and any linked instances.
exitWithCode({required int statusCode}) → void
Exit the current instance and any linked instances, reporting the specified status code to the host.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited