exitWithCode abstract method

void exitWithCode({
  1. required int statusCode,
})

Exit the current instance and any linked instances, reporting the specified status code to the host.

The meaning of the code depends on the context, with 0 usually meaning "success", and other values indicating various types of failure.

This function does not return; the effect is analogous to a trap, but without the connotation that something bad has happened.

Implementation

void exitWithCode({required int statusCode});