writeViaStream abstract method
Write the given stream to stderr.
If the stream's writable end is dropped this function will either return success once the entire contents of the stream have been written or an error-code representing a failure.
Otherwise if there is an error the readable end of the stream will be dropped and this function will return an error-code.
Implementation
Future<i0.Result<void, TypesErrorCode>> writeViaStream({
required Stream<i1.Uint8List> data,
});