MonotonicClock class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getResolution() int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
now() int
toString() String
A string representation of this object.
inherited
waitFor({required int howLong}) Future<void>
waitUntil({required int when}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited