TypesDescriptorType class sealed
Constructors
- TypesDescriptorType.blockDevice()
-
constfactory
- TypesDescriptorType.characterDevice()
-
constfactory
- TypesDescriptorType.directory()
-
constfactory
- TypesDescriptorType.fifo()
-
constfactory
- TypesDescriptorType.other(dynamic payload)
-
constfactory
- TypesDescriptorType.regularFile()
-
constfactory
- TypesDescriptorType.socket()
-
constfactory
- TypesDescriptorType.symbolicLink()
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited