TypesErrorCode class sealed
- Implementers
- TypesErrorCodeAccess
- TypesErrorCodeAlready
- TypesErrorCodeBadDescriptor
- TypesErrorCodeBusy
- TypesErrorCodeCrossDevice
- TypesErrorCodeDeadlock
- TypesErrorCodeExist
- TypesErrorCodeFileTooLarge
- TypesErrorCodeIllegalByteSequence
- TypesErrorCodeInProgress
- TypesErrorCodeInsufficientMemory
- TypesErrorCodeInsufficientSpace
- TypesErrorCodeInterrupted
- TypesErrorCodeInvalid
- TypesErrorCodeInvalidSeek
- TypesErrorCodeIo
- TypesErrorCodeIsDirectory
- TypesErrorCodeLoop
- TypesErrorCodeMessageSize
- TypesErrorCodeNameTooLong
- TypesErrorCodeNoDevice
- TypesErrorCodeNoEntry
- TypesErrorCodeNoLock
- TypesErrorCodeNoSuchDevice
- TypesErrorCodeNotDirectory
- TypesErrorCodeNotEmpty
- TypesErrorCodeNotPermitted
- TypesErrorCodeNotRecoverable
- TypesErrorCodeNoTty
- TypesErrorCodeOther
- TypesErrorCodeOverflow
- TypesErrorCodePipe
- TypesErrorCodeQuota
- TypesErrorCodeReadOnly
- TypesErrorCodeTextFileBusy
- TypesErrorCodeTooManyLinks
- TypesErrorCodeUnsupported
Constructors
- TypesErrorCode.access()
-
constfactory
- TypesErrorCode.already()
-
constfactory
- TypesErrorCode.badDescriptor()
-
constfactory
- TypesErrorCode.busy()
-
constfactory
- TypesErrorCode.crossDevice()
-
constfactory
- TypesErrorCode.deadlock()
-
constfactory
- TypesErrorCode.exist()
-
constfactory
- TypesErrorCode.fileTooLarge()
-
constfactory
- TypesErrorCode.illegalByteSequence()
-
constfactory
- TypesErrorCode.inProgress()
-
constfactory
- TypesErrorCode.insufficientMemory()
-
constfactory
- TypesErrorCode.insufficientSpace()
-
constfactory
- TypesErrorCode.interrupted()
-
constfactory
- TypesErrorCode.invalid()
-
constfactory
- TypesErrorCode.invalidSeek()
-
constfactory
- TypesErrorCode.io()
-
constfactory
- TypesErrorCode.isDirectory()
-
constfactory
- TypesErrorCode.loop()
-
constfactory
- TypesErrorCode.messageSize()
-
constfactory
- TypesErrorCode.nameTooLong()
-
constfactory
- TypesErrorCode.noDevice()
-
constfactory
- TypesErrorCode.noEntry()
-
constfactory
- TypesErrorCode.noLock()
-
constfactory
- TypesErrorCode.noSuchDevice()
-
constfactory
- TypesErrorCode.notDirectory()
-
constfactory
- TypesErrorCode.notEmpty()
-
constfactory
- TypesErrorCode.notPermitted()
-
constfactory
- TypesErrorCode.notRecoverable()
-
constfactory
- TypesErrorCode.noTty()
-
constfactory
- TypesErrorCode.other(dynamic payload)
-
constfactory
- TypesErrorCode.overflow()
-
constfactory
- TypesErrorCode.pipe()
-
constfactory
- TypesErrorCode.quota()
-
constfactory
- TypesErrorCode.readOnly()
-
constfactory
- TypesErrorCode.textFileBusy()
-
constfactory
- TypesErrorCode.tooManyLinks()
-
constfactory
- TypesErrorCode.unsupported()
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited