Client class abstract interface

This interface defines an HTTP client for sending "outgoing" requests.

Most components are expected to import this interface to provide the capability to send HTTP requests to arbitrary destinations on a network.

The type signature of client.send is the same as handler.handle. This duplication is currently necessary because some Component Model tooling (including WIT itself) is unable to represent a component importing two instances of the same interface. A client.send import may be linked directly to a handler.handle export to bypass the network.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send({required dynamic request}) Future<Result<dynamic, TypesErrorCode>>
This function may be used to either send an outgoing request over the network or to forward it to another component.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited