send abstract method
This function may be used to either send an outgoing request over the network or to forward it to another component.
Implementation
Future<i0.Result<i0.Owned<TypesResponse>, TypesErrorCode>> send({
required i0.Owned<TypesRequest> request,
});