handle abstract method
This function may be called with either an incoming request read from the network or a request synthesized or forwarded by another component.
Implementation
Future<i0.Result<i0.Owned<TypesResponse>, TypesErrorCode>> handle({
required i0.Owned<TypesRequest> request,
});