TypesErrorCode class sealed

Implementers

Constructors

TypesErrorCode.configurationError()
const
factory
TypesErrorCode.connectionLimitReached()
const
factory
TypesErrorCode.connectionReadTimeout()
const
factory
TypesErrorCode.connectionRefused()
const
factory
TypesErrorCode.connectionTerminated()
const
factory
TypesErrorCode.connectionTimeout()
const
factory
TypesErrorCode.connectionWriteTimeout()
const
factory
TypesErrorCode.destinationIpProhibited()
const
factory
TypesErrorCode.destinationIpUnroutable()
const
factory
TypesErrorCode.destinationNotFound()
const
factory
TypesErrorCode.destinationUnavailable()
const
factory
TypesErrorCode.dnsError(({dynamic infoCode, dynamic rcode}) payload)
const
factory
TypesErrorCode.dnsTimeout()
const
factory
TypesErrorCode.httpProtocolError()
const
factory
TypesErrorCode.httpRequestBodySize(dynamic payload)
const
factory
TypesErrorCode.httpRequestDenied()
const
factory
TypesErrorCode.httpRequestHeaderSectionSize(dynamic payload)
const
factory
TypesErrorCode.httpRequestHeaderSize(dynamic payload)
const
factory
TypesErrorCode.httpRequestLengthRequired()
const
factory
TypesErrorCode.httpRequestMethodInvalid()
const
factory
TypesErrorCode.httpRequestTrailerSectionSize(dynamic payload)
const
factory
TypesErrorCode.httpRequestTrailerSize(({dynamic fieldName, dynamic fieldSize}) payload)
const
factory
TypesErrorCode.httpRequestUriInvalid()
const
factory
TypesErrorCode.httpRequestUriTooLong()
const
factory
TypesErrorCode.httpResponseBodySize(dynamic payload)
const
factory
TypesErrorCode.httpResponseContentCoding(dynamic payload)
const
factory
TypesErrorCode.httpResponseHeaderSectionSize(dynamic payload)
const
factory
TypesErrorCode.httpResponseHeaderSize(({dynamic fieldName, dynamic fieldSize}) payload)
const
factory
TypesErrorCode.httpResponseIncomplete()
const
factory
TypesErrorCode.httpResponseTimeout()
const
factory
TypesErrorCode.httpResponseTrailerSectionSize(dynamic payload)
const
factory
TypesErrorCode.httpResponseTrailerSize(({dynamic fieldName, dynamic fieldSize}) payload)
const
factory
TypesErrorCode.httpResponseTransferCoding(dynamic payload)
const
factory
TypesErrorCode.httpUpgradeFailed()
const
factory
TypesErrorCode.internalError(dynamic payload)
const
factory
TypesErrorCode.loopDetected()
const
factory
TypesErrorCode.tlsAlertReceived(({dynamic alertId, dynamic alertMessage}) payload)
const
factory
TypesErrorCode.tlsCertificateError()
const
factory
TypesErrorCode.tlsProtocolError()
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited