TypesMethod class sealed

This type corresponds to HTTP standard Methods.

Implementers

Constructors

TypesMethod.connect()
const
factory
TypesMethod.delete()
const
factory
TypesMethod.get()
const
factory
TypesMethod.head()
const
factory
TypesMethod.options()
const
factory
TypesMethod.other(String payload)
const
factory
TypesMethod.patch()
const
factory
TypesMethod.post()
const
factory
TypesMethod.put()
const
factory
TypesMethod.trace()
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited