TypesRequestOptionsError class sealed

This type enumerates the different kinds of errors that may occur when setting fields of a request-options resource.

Implementers

Constructors

TypesRequestOptionsError.immutable()
const
factory
TypesRequestOptionsError.notSupported()
const
factory
TypesRequestOptionsError.other(dynamic payload)
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited