TypesErrorCode class sealed
- Implementers
- TypesErrorCodeAccessDenied
- TypesErrorCodeAddressInUse
- TypesErrorCodeAddressNotBindable
- TypesErrorCodeConnectionAborted
- TypesErrorCodeConnectionBroken
- TypesErrorCodeConnectionRefused
- TypesErrorCodeConnectionReset
- TypesErrorCodeDatagramTooLarge
- TypesErrorCodeInvalidArgument
- TypesErrorCodeInvalidState
- TypesErrorCodeNotSupported
- TypesErrorCodeOther
- TypesErrorCodeOutOfMemory
- TypesErrorCodeRemoteUnreachable
- TypesErrorCodeTimeout
Constructors
- TypesErrorCode.accessDenied()
-
constfactory
- TypesErrorCode.addressInUse()
-
constfactory
- TypesErrorCode.addressNotBindable()
-
constfactory
- TypesErrorCode.connectionAborted()
-
constfactory
- TypesErrorCode.connectionBroken()
-
constfactory
- TypesErrorCode.connectionRefused()
-
constfactory
- TypesErrorCode.connectionReset()
-
constfactory
- TypesErrorCode.datagramTooLarge()
-
constfactory
- TypesErrorCode.invalidArgument()
-
constfactory
- TypesErrorCode.invalidState()
-
constfactory
- TypesErrorCode.notSupported()
-
constfactory
- TypesErrorCode.other(dynamic payload)
-
constfactory
- TypesErrorCode.outOfMemory()
-
constfactory
- TypesErrorCode.remoteUnreachable()
-
constfactory
- TypesErrorCode.timeout()
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited