Constructors
-
TypesIpAddress.ipv4((int, int, int, int) payload)
-
const
factory
-
TypesIpAddress.ipv6((int, int, int, int, int, int, int, int) payload)
-
const
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited