TypesIpAddressIpv4 class final

Inheritance

Constructors

TypesIpAddressIpv4((int, int, int, int) payload)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
payload → (int, int, int, int)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited