CommandImports class final

Properties

cliEnvironment Environment
no setter
cliExit Exit
no setter
cliStderr Stderr
no setter
cliStdin Stdin
no setter
cliStdout Stdout
no setter
cliTerminalStderr TerminalStderr
no setter
cliTerminalStdin TerminalStdin
no setter
cliTerminalStdout TerminalStdout
no setter
clocksMonotonicClock MonotonicClock
no setter
clocksSystemClock SystemClock
no setter
filesystemPreopens Preopens
no setter
filesystemTypes → Types
no setter
hashCode int
The hash code for this object.
no setterinherited
randomInsecure Insecure
no setter
randomInsecureSeed InsecureSeed
no setter
randomRandom Random
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socketsIpNameLookup IpNameLookup
no setter
socketsTypes → Types
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited