This interface defines a handler of HTTP Requests.
In a wasi:http/service this interface is exported to respond to an
incoming HTTP Request with a Response.
In wasi:http/middleware this interface is both exported and imported as
the "downstream" and "upstream" directions of the middleware chain.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
handle(
{required dynamic request}) → Future< Result< dynamic, TypesErrorCode> > - This function may be called with either an incoming request read from the network or a request synthesized or forwarded by another component.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited