TypesErrorCode class sealed
These cases are inspired by the IANA HTTP Proxy Error Types: www.iana.org/assignments/http-proxy-status/http-proxy-status.xhtml#table-http-proxy-error-types
- Implementers
- TypesErrorCodeConfigurationError
- TypesErrorCodeConnectionLimitReached
- TypesErrorCodeConnectionReadTimeout
- TypesErrorCodeConnectionRefused
- TypesErrorCodeConnectionTerminated
- TypesErrorCodeConnectionTimeout
- TypesErrorCodeConnectionWriteTimeout
- TypesErrorCodeDestinationIpProhibited
- TypesErrorCodeDestinationIpUnroutable
- TypesErrorCodeDestinationNotFound
- TypesErrorCodeDestinationUnavailable
- TypesErrorCodeDnsError
- TypesErrorCodeDnsTimeout
- TypesErrorCodeHttpProtocolError
- TypesErrorCodeHttpRequestBodySize
- TypesErrorCodeHttpRequestDenied
- TypesErrorCodeHttpRequestHeaderSectionSize
- TypesErrorCodeHttpRequestHeaderSize
- TypesErrorCodeHttpRequestLengthRequired
- TypesErrorCodeHttpRequestMethodInvalid
- TypesErrorCodeHttpRequestTrailerSectionSize
- TypesErrorCodeHttpRequestTrailerSize
- TypesErrorCodeHttpRequestUriInvalid
- TypesErrorCodeHttpRequestUriTooLong
- TypesErrorCodeHttpResponseBodySize
- TypesErrorCodeHttpResponseContentCoding
- TypesErrorCodeHttpResponseHeaderSectionSize
- TypesErrorCodeHttpResponseHeaderSize
- TypesErrorCodeHttpResponseIncomplete
- TypesErrorCodeHttpResponseTimeout
- TypesErrorCodeHttpResponseTrailerSectionSize
- TypesErrorCodeHttpResponseTrailerSize
- TypesErrorCodeHttpResponseTransferCoding
- TypesErrorCodeHttpUpgradeFailed
- TypesErrorCodeInternalError
- TypesErrorCodeLoopDetected
- TypesErrorCodeTlsAlertReceived
- TypesErrorCodeTlsCertificateError
- TypesErrorCodeTlsProtocolError
Constructors
- TypesErrorCode.configurationError()
-
constfactory
- TypesErrorCode.connectionLimitReached()
-
constfactory
- TypesErrorCode.connectionReadTimeout()
-
constfactory
- TypesErrorCode.connectionRefused()
-
constfactory
- TypesErrorCode.connectionTerminated()
-
constfactory
- TypesErrorCode.connectionTimeout()
-
constfactory
- TypesErrorCode.connectionWriteTimeout()
-
constfactory
- TypesErrorCode.destinationIpProhibited()
-
constfactory
- TypesErrorCode.destinationIpUnroutable()
-
constfactory
- TypesErrorCode.destinationNotFound()
-
constfactory
-
constfactory
- TypesErrorCode.dnsError(({dynamic infoCode, dynamic rcode}) payload)
-
constfactory
- TypesErrorCode.dnsTimeout()
-
constfactory
- TypesErrorCode.httpProtocolError()
-
constfactory
- TypesErrorCode.httpRequestBodySize(dynamic payload)
-
constfactory
- TypesErrorCode.httpRequestDenied()
-
constfactory
- TypesErrorCode.httpRequestHeaderSectionSize(dynamic payload)
-
constfactory
- TypesErrorCode.httpRequestHeaderSize(dynamic payload)
-
constfactory
- TypesErrorCode.httpRequestLengthRequired()
-
constfactory
- TypesErrorCode.httpRequestMethodInvalid()
-
constfactory
- TypesErrorCode.httpRequestTrailerSectionSize(dynamic payload)
-
constfactory
- TypesErrorCode.httpRequestTrailerSize(({dynamic fieldName, dynamic fieldSize}) payload)
-
constfactory
- TypesErrorCode.httpRequestUriInvalid()
-
constfactory
- TypesErrorCode.httpRequestUriTooLong()
-
constfactory
- TypesErrorCode.httpResponseBodySize(dynamic payload)
-
constfactory
- TypesErrorCode.httpResponseContentCoding(dynamic payload)
-
constfactory
- TypesErrorCode.httpResponseHeaderSectionSize(dynamic payload)
-
constfactory
- TypesErrorCode.httpResponseHeaderSize(({dynamic fieldName, dynamic fieldSize}) payload)
-
constfactory
- TypesErrorCode.httpResponseIncomplete()
-
constfactory
- TypesErrorCode.httpResponseTimeout()
-
constfactory
- TypesErrorCode.httpResponseTrailerSectionSize(dynamic payload)
-
constfactory
- TypesErrorCode.httpResponseTrailerSize(({dynamic fieldName, dynamic fieldSize}) payload)
-
constfactory
- TypesErrorCode.httpResponseTransferCoding(dynamic payload)
-
constfactory
- TypesErrorCode.httpUpgradeFailed()
-
constfactory
- TypesErrorCode.internalError(dynamic payload)
-
constfactory
- TypesErrorCode.loopDetected()
-
constfactory
- TypesErrorCode.tlsAlertReceived(({dynamic alertId, dynamic alertMessage}) payload)
-
constfactory
- TypesErrorCode.tlsCertificateError()
-
constfactory
- TypesErrorCode.tlsProtocolError()
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited