TypesFields class final

This following block defines the fields resource which corresponds to HTTP standard Fields. Fields are a common representation used for both Headers and Trailers.

A fields may be mutable or immutable. A fields created using the constructor, from-list, or clone will be mutable, but a fields resource given by other means (including, but not limited to, request.headers) might be be immutable. In an immutable fields, the set, append, and delete operations will fail with header-error.immutable.

A fields resource should store field-names and field-values in their original casing used to construct or mutate the fields resource. The fields resource should use that original casing when serializing the fields for transport or when returning them from a method.

Implementations may impose limits on individual field values and on total aggregate field section size. Operations that would exceed these limits fail with header-error.size-exceeded

Constructors

TypesFields()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited