TypesHeaderError class sealed

This type enumerates the different kinds of errors that may occur when setting or appending to a fields resource.

Implementers

Constructors

TypesHeaderError.forbidden()
const
factory
TypesHeaderError.immutable()
const
factory
TypesHeaderError.invalidSyntax()
const
factory
TypesHeaderError.other(dynamic payload)
const
factory
TypesHeaderError.sizeExceeded()
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited