TypesHeaderError class sealed
This type enumerates the different kinds of errors that may occur when
setting or appending to a fields resource.
Constructors
- TypesHeaderError.forbidden()
-
constfactory
- TypesHeaderError.immutable()
-
constfactory
- TypesHeaderError.invalidSyntax()
-
constfactory
- TypesHeaderError.other(dynamic payload)
-
constfactory
- TypesHeaderError.sizeExceeded()
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited