TypesMethod class sealed
This type corresponds to HTTP standard Methods.
Constructors
- TypesMethod.connect()
-
constfactory
- TypesMethod.delete()
-
constfactory
- TypesMethod.get()
-
constfactory
- TypesMethod.head()
-
constfactory
- TypesMethod.options()
-
constfactory
- TypesMethod.other(String payload)
-
constfactory
- TypesMethod.patch()
-
constfactory
- TypesMethod.post()
-
constfactory
- TypesMethod.put()
-
constfactory
- TypesMethod.trace()
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited