TypesIpSocketAddressIpv4 class final

Inheritance

Constructors

TypesIpSocketAddressIpv4(({(int, int, int, int) address, int port}) payload)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
payload → ({(int, int, int, int) address, int port})
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited